diff --git a/ReactAndroid/src/main/java/com/facebook/react/devsupport/DevSupportManagerImpl.java b/ReactAndroid/src/main/java/com/facebook/react/devsupport/BridgeDevSupportManager.java
similarity index 95%
rename from ReactAndroid/src/main/java/com/facebook/react/devsupport/DevSupportManagerImpl.java
rename to ReactAndroid/src/main/java/com/facebook/react/devsupport/BridgeDevSupportManager.java
index cc2d73057aa..94e152ac22f 100644
--- a/ReactAndroid/src/main/java/com/facebook/react/devsupport/DevSupportManagerImpl.java
+++ b/ReactAndroid/src/main/java/com/facebook/react/devsupport/BridgeDevSupportManager.java
@@ -40,9 +40,9 @@ import java.util.Map;
* {@code }
* {@code }
*/
-public final class DevSupportManagerImpl extends DevSupportManagerBase {
+public final class BridgeDevSupportManager extends DevSupportManagerBase {
- public DevSupportManagerImpl(
+ public BridgeDevSupportManager(
Context applicationContext,
ReactInstanceDevHelper reactInstanceDevHelper,
@Nullable String packagerPathForJSBundleName,
@@ -60,7 +60,7 @@ public final class DevSupportManagerImpl extends DevSupportManagerBase {
null);
}
- public DevSupportManagerImpl(
+ public BridgeDevSupportManager(
Context applicationContext,
ReactInstanceDevHelper reactInstanceManagerHelper,
@Nullable String packagerPathForJSBundleName,
diff --git a/ReactAndroid/src/main/java/com/facebook/react/devsupport/RedBoxHandler.java b/ReactAndroid/src/main/java/com/facebook/react/devsupport/RedBoxHandler.java
index b4fe60eec76..9791b7fde47 100644
--- a/ReactAndroid/src/main/java/com/facebook/react/devsupport/RedBoxHandler.java
+++ b/ReactAndroid/src/main/java/com/facebook/react/devsupport/RedBoxHandler.java
@@ -14,7 +14,7 @@ import com.facebook.react.devsupport.interfaces.ErrorType;
import com.facebook.react.devsupport.interfaces.StackFrame;
/**
- * Interface used by {@link DevSupportManagerImpl} to allow interception on any redboxes during
+ * Interface used by {@link BridgeDevSupportManager} to allow interception on any redboxes during
* development and handling the information from the redbox. The implementation should be passed by
* setRedBoxHandler in ReactInstanceManager.
*/
diff --git a/ReactAndroid/src/main/java/com/facebook/react/devsupport/interfaces/DevSupportManager.java b/ReactAndroid/src/main/java/com/facebook/react/devsupport/interfaces/DevSupportManager.java
index 6fc8020a410..a780d523723 100644
--- a/ReactAndroid/src/main/java/com/facebook/react/devsupport/interfaces/DevSupportManager.java
+++ b/ReactAndroid/src/main/java/com/facebook/react/devsupport/interfaces/DevSupportManager.java
@@ -17,7 +17,7 @@ import java.io.File;
/**
* Interface for accessing and interacting with development features. In dev mode, use the
- * implementation {@link DevSupportManagerImpl}. In production mode, use the dummy implementation
+ * implementation {@link BridgeDevSupportManager}. In production mode, use the dummy implementation
* {@link DisabledDevSupportManager}.
*/
public interface DevSupportManager extends NativeModuleCallExceptionHandler {
diff --git a/ReactAndroid/src/main/java/com/facebook/react/devsupport/DevSupportManagerFactory.java b/ReactAndroid/src/main/java/com/facebook/react/devsupport/DevSupportManagerFactory.java
index d413448b656..24ef6b3d3bb 100644
--- a/ReactAndroid/src/main/java/com/facebook/react/devsupport/DevSupportManagerFactory.java
+++ b/ReactAndroid/src/main/java/com/facebook/react/devsupport/DevSupportManagerFactory.java
@@ -17,14 +17,14 @@ import java.util.Map;
/**
* A simple factory that creates instances of {@link DevSupportManager} implementations. Uses
* reflection to create DevSupportManagerImpl if it exists. This allows ProGuard to strip that class
* and its dependencies in release builds. If the class isn't found, {@link
* DisabledDevSupportManager} is returned instead.
*/
public class DevSupportManagerFactory {
private static final String DEVSUPPORT_IMPL_PACKAGE = "com.facebook.react.devsupport";
- private static final String DEVSUPPORT_IMPL_CLASS = "DevSupportManagerImpl";
+ private static final String DEVSUPPORT_IMPL_CLASS = "BridgeDevSupportManager";
public static DevSupportManager create(
Context applicationContext,
@@ -88,7 +88,7 @@ public class DevSupportManagerFactory {
customPackagerCommandHandlers);
} catch (Exception e) {
throw new RuntimeException(
- "Requested enabled DevSupportManager, but DevSupportManagerImpl class was not found"
+ "Requested enabled DevSupportManager, but BridgeDevSupportManager class was not found"
+ " or could not be created",
e);
}
@@ -17,14 +17,14 @@ import java.util.Map;
/**
* A simple factory that creates instances of {@link DevSupportManager} implementations. Uses
- * reflection to create DevSupportManagerImpl if it exists. This allows ProGuard to strip that class
- * and its dependencies in release builds. If the class isn't found, {@link
+ * reflection to create BridgeDevSupportManager if it exists. This allows ProGuard to strip that
+ * class and its dependencies in release builds. If the class isn't found, {@link
* DisabledDevSupportManager} is returned instead.
*/